# lakefs-client
lakeFS HTTP API

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.1.0
- Package version: 0.97.3
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python &gt;&#x3D;3.7

## Migration from other generators like python and python-legacy

### Changes
1. This generator uses spec case for all (object) property names and parameter names.
    - So if the spec has a property name like camelCase, it will use camelCase rather than camel_case
    - So you will need to update how you input and read properties to use spec case
2. Endpoint parameters are stored in dictionaries to prevent collisions (explanation below)
    - So you will need to update how you pass data in to endpoints
3. Endpoint responses now include the original response, the deserialized response body, and (todo)the deserialized headers
    - So you will need to update your code to use response.body to access deserialized data
4. All validated data is instantiated in an instance that subclasses all validated Schema classes and Decimal/str/list/tuple/frozendict/NoneClass/BoolClass/bytes/io.FileIO
    - This means that you can use isinstance to check if a payload validated against a schema class
    - This means that no data will be of type None/True/False
        - ingested None will subclass NoneClass
        - ingested True will subclass BoolClass
        - ingested False will subclass BoolClass
        - So if you need to check is True/False/None, instead use instance.is_true_oapg()/.is_false_oapg()/.is_none_oapg()
5. All validated class instances are immutable except for ones based on io.File
    - This is because if properties were changed after validation, that validation would no longer apply
    - So no changing values or property values after a class has been instantiated
6. String + Number types with formats
    - String type data is stored as a string and if you need to access types based on its format like date,
    date-time, uuid, number etc then you will need to use accessor functions on the instance
    - type string + format: See .as_date_oapg, .as_datetime_oapg, .as_decimal_oapg, .as_uuid_oapg
    - type number + format: See .as_float_oapg, .as_int_oapg
    - this was done because openapi/json-schema defines constraints. string data may be type string with no format
    keyword in one schema, and include a format constraint in another schema
    - So if you need to access a string format based type, use as_date_oapg/as_datetime_oapg/as_decimal_oapg/as_uuid_oapg
    - So if you need to access a number format based type, use as_int_oapg/as_float_oapg
7. Property access on AnyType(type unset) or object(dict) schemas
    - Only required keys with valid python names are properties like .someProp and have type hints
    - All optional keys may not exist, so properties are not defined for them
    - One can access optional values with dict_instance['optionalProp'] and KeyError will be raised if it does not exist
    - Use get_item_oapg if you need a way to always get a value whether or not the key exists
        - If the key does not exist, schemas.unset is returned from calling dict_instance.get_item_oapg('optionalProp')
        - All required and optional keys have type hints for this method, and @typing.overload is used
        - A type hint is also generated for additionalProperties accessed using this method
    - So you will need to update you code to use some_instance['optionalProp'] to access optional property
    and additionalProperty values
8. The location of the api classes has changed
    - Api classes are located in your_package.apis.tags.some_api
    - This change was made to eliminate redundant code generation
    - Legacy generators generated the same endpoint twice if it had > 1 tag on it
    - This generator defines an endpoint in one class, then inherits that class to generate
      apis by tags and by paths
    - This change reduces code and allows quicker run time if you use the path apis
        - path apis are at your_package.apis.paths.some_path
    - Those apis will only load their needed models, which is less to load than all of the resources needed in a tag api
    - So you will need to update your import paths to the api classes

### Why are Oapg and _oapg used in class and method names?
Classes can have arbitrarily named properties set on them
Endpoints can have arbitrary operationId method names set
For those reasons, I use the prefix Oapg and _oapg to greatly reduce the likelihood of collisions
on protected + public classes/methods.
oapg stands for OpenApi Python Generator.

### Object property spec case
This was done because when payloads are ingested, they can be validated against N number of schemas.
If the input signature used a different property name then that has mutated the payload.
So SchemaA and SchemaB must both see the camelCase spec named variable.
Also it is possible to send in two properties, named camelCase and camel_case in the same payload.
That use case should be support so spec case is used.

### Parameter spec case
Parameters can be included in different locations including:
- query
- path
- header
- cookie

Any of those parameters could use the same parameter names, so if every parameter
was included as an endpoint parameter in a function signature, they would collide.
For that reason, each of those inputs have been separated out into separate typed dictionaries:
- query_params
- path_params
- header_params
- cookie_params

So when updating your code, you will need to pass endpoint parameters in using those
dictionaries.

### Endpoint responses
Endpoint responses have been enriched to now include more information.
Any response reom an endpoint will now include the following properties:
response: urllib3.HTTPResponse
body: typing.Union[Unset, Schema]
headers: typing.Union[Unset, TODO]
Note: response header deserialization has not yet been added


## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/treeverse/lakeFS.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/treeverse/lakeFS.git`)

Then import the package:
```python
import lakefs_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import lakefs_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import lakefs_client
from pprint import pprint
from lakefs_client.apis.tags import actions_api
from lakefs_client.model.action_run import ActionRun
from lakefs_client.model.action_run_list import ActionRunList
from lakefs_client.model.error import Error
from lakefs_client.model.hook_run_list import HookRunList
# Defining the host is optional and defaults to /api/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = lakefs_client.Configuration(
    host = "/api/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basic_auth
configuration = lakefs_client.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: cookie_auth
configuration.api_key['cookie_auth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['cookie_auth'] = 'Bearer'

# Configure API key authorization: oidc_auth
configuration.api_key['oidc_auth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['oidc_auth'] = 'Bearer'

# Configure API key authorization: saml_auth
configuration.api_key['saml_auth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['saml_auth'] = 'Bearer'

# Configure Bearer authorization (JWT): jwt_token
configuration = lakefs_client.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# Enter a context with an instance of the API client
with lakefs_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = actions_api.ActionsApi(api_client)
    repository = "repository_example" # str | 
run_id = "run_id_example" # str | 

    try:
        # get a run
        api_response = api_instance.get_run(repositoryrun_id)
        pprint(api_response)
    except lakefs_client.ApiException as e:
        print("Exception when calling ActionsApi->get_run: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to */api/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActionsApi* | [**get_run**](docs/apis/tags/ActionsApi.md#get_run) | **get** /repositories/{repository}/actions/runs/{run_id} | get a run
*ActionsApi* | [**get_run_hook_output**](docs/apis/tags/ActionsApi.md#get_run_hook_output) | **get** /repositories/{repository}/actions/runs/{run_id}/hooks/{hook_run_id}/output | get run hook output
*ActionsApi* | [**list_repository_runs**](docs/apis/tags/ActionsApi.md#list_repository_runs) | **get** /repositories/{repository}/actions/runs | list runs
*ActionsApi* | [**list_run_hooks**](docs/apis/tags/ActionsApi.md#list_run_hooks) | **get** /repositories/{repository}/actions/runs/{run_id}/hooks | list run hooks
*AuthApi* | [**add_group_membership**](docs/apis/tags/AuthApi.md#add_group_membership) | **put** /auth/groups/{groupId}/members/{userId} | add group membership
*AuthApi* | [**attach_policy_to_group**](docs/apis/tags/AuthApi.md#attach_policy_to_group) | **put** /auth/groups/{groupId}/policies/{policyId} | attach policy to group
*AuthApi* | [**attach_policy_to_user**](docs/apis/tags/AuthApi.md#attach_policy_to_user) | **put** /auth/users/{userId}/policies/{policyId} | attach policy to user
*AuthApi* | [**create_credentials**](docs/apis/tags/AuthApi.md#create_credentials) | **post** /auth/users/{userId}/credentials | create credentials
*AuthApi* | [**create_group**](docs/apis/tags/AuthApi.md#create_group) | **post** /auth/groups | create group
*AuthApi* | [**create_policy**](docs/apis/tags/AuthApi.md#create_policy) | **post** /auth/policies | create policy
*AuthApi* | [**create_user**](docs/apis/tags/AuthApi.md#create_user) | **post** /auth/users | create user
*AuthApi* | [**delete_credentials**](docs/apis/tags/AuthApi.md#delete_credentials) | **delete** /auth/users/{userId}/credentials/{accessKeyId} | delete credentials
*AuthApi* | [**delete_group**](docs/apis/tags/AuthApi.md#delete_group) | **delete** /auth/groups/{groupId} | delete group
*AuthApi* | [**delete_group_membership**](docs/apis/tags/AuthApi.md#delete_group_membership) | **delete** /auth/groups/{groupId}/members/{userId} | delete group membership
*AuthApi* | [**delete_policy**](docs/apis/tags/AuthApi.md#delete_policy) | **delete** /auth/policies/{policyId} | delete policy
*AuthApi* | [**delete_user**](docs/apis/tags/AuthApi.md#delete_user) | **delete** /auth/users/{userId} | delete user
*AuthApi* | [**detach_policy_from_group**](docs/apis/tags/AuthApi.md#detach_policy_from_group) | **delete** /auth/groups/{groupId}/policies/{policyId} | detach policy from group
*AuthApi* | [**detach_policy_from_user**](docs/apis/tags/AuthApi.md#detach_policy_from_user) | **delete** /auth/users/{userId}/policies/{policyId} | detach policy from user
*AuthApi* | [**forgot_password**](docs/apis/tags/AuthApi.md#forgot_password) | **post** /auth/password/forgot | forgot password request initiates the password reset process
*AuthApi* | [**get_auth_capabilities**](docs/apis/tags/AuthApi.md#get_auth_capabilities) | **get** /auth/capabilities | list authentication capabilities supported
*AuthApi* | [**get_credentials**](docs/apis/tags/AuthApi.md#get_credentials) | **get** /auth/users/{userId}/credentials/{accessKeyId} | get credentials
*AuthApi* | [**get_current_user**](docs/apis/tags/AuthApi.md#get_current_user) | **get** /user | get current user
*AuthApi* | [**get_group**](docs/apis/tags/AuthApi.md#get_group) | **get** /auth/groups/{groupId} | get group
*AuthApi* | [**get_policy**](docs/apis/tags/AuthApi.md#get_policy) | **get** /auth/policies/{policyId} | get policy
*AuthApi* | [**get_user**](docs/apis/tags/AuthApi.md#get_user) | **get** /auth/users/{userId} | get user
*AuthApi* | [**list_group_members**](docs/apis/tags/AuthApi.md#list_group_members) | **get** /auth/groups/{groupId}/members | list group members
*AuthApi* | [**list_group_policies**](docs/apis/tags/AuthApi.md#list_group_policies) | **get** /auth/groups/{groupId}/policies | list group policies
*AuthApi* | [**list_groups**](docs/apis/tags/AuthApi.md#list_groups) | **get** /auth/groups | list groups
*AuthApi* | [**list_policies**](docs/apis/tags/AuthApi.md#list_policies) | **get** /auth/policies | list policies
*AuthApi* | [**list_user_credentials**](docs/apis/tags/AuthApi.md#list_user_credentials) | **get** /auth/users/{userId}/credentials | list user credentials
*AuthApi* | [**list_user_groups**](docs/apis/tags/AuthApi.md#list_user_groups) | **get** /auth/users/{userId}/groups | list user groups
*AuthApi* | [**list_user_policies**](docs/apis/tags/AuthApi.md#list_user_policies) | **get** /auth/users/{userId}/policies | list user policies
*AuthApi* | [**list_users**](docs/apis/tags/AuthApi.md#list_users) | **get** /auth/users | list users
*AuthApi* | [**login**](docs/apis/tags/AuthApi.md#login) | **post** /auth/login | perform a login
*AuthApi* | [**update_password**](docs/apis/tags/AuthApi.md#update_password) | **post** /auth/password | Update user password by reset_password token
*AuthApi* | [**update_policy**](docs/apis/tags/AuthApi.md#update_policy) | **put** /auth/policies/{policyId} | update policy
*BranchesApi* | [**cherry_pick**](docs/apis/tags/BranchesApi.md#cherry_pick) | **post** /repositories/{repository}/branches/{branch}/cherry-pick | Replay the changes from the given commit on the branch
*BranchesApi* | [**create_branch**](docs/apis/tags/BranchesApi.md#create_branch) | **post** /repositories/{repository}/branches | create branch
*BranchesApi* | [**delete_branch**](docs/apis/tags/BranchesApi.md#delete_branch) | **delete** /repositories/{repository}/branches/{branch} | delete branch
*BranchesApi* | [**diff_branch**](docs/apis/tags/BranchesApi.md#diff_branch) | **get** /repositories/{repository}/branches/{branch}/diff | diff branch
*BranchesApi* | [**get_branch**](docs/apis/tags/BranchesApi.md#get_branch) | **get** /repositories/{repository}/branches/{branch} | get branch
*BranchesApi* | [**list_branches**](docs/apis/tags/BranchesApi.md#list_branches) | **get** /repositories/{repository}/branches | list branches
*BranchesApi* | [**reset_branch**](docs/apis/tags/BranchesApi.md#reset_branch) | **put** /repositories/{repository}/branches/{branch} | reset branch
*BranchesApi* | [**revert_branch**](docs/apis/tags/BranchesApi.md#revert_branch) | **post** /repositories/{repository}/branches/{branch}/revert | revert
*CommitsApi* | [**commit**](docs/apis/tags/CommitsApi.md#commit) | **post** /repositories/{repository}/branches/{branch}/commits | create commit
*CommitsApi* | [**get_commit**](docs/apis/tags/CommitsApi.md#get_commit) | **get** /repositories/{repository}/commits/{commitId} | get commit
*CommitsApi* | [**log_branch_commits**](docs/apis/tags/CommitsApi.md#log_branch_commits) | **get** /repositories/{repository}/branches/{branch}/commits | get commit log from branch. Deprecated: replaced by logCommits by passing branch name as ref 
*ConfigApi* | [**get_garbage_collection_config**](docs/apis/tags/ConfigApi.md#get_garbage_collection_config) | **get** /config/garbage-collection | 
*ConfigApi* | [**get_lake_fs_version**](docs/apis/tags/ConfigApi.md#get_lake_fs_version) | **get** /config/version | 
*ConfigApi* | [**get_setup_state**](docs/apis/tags/ConfigApi.md#get_setup_state) | **get** /setup_lakefs | check if the lakeFS installation is already set up
*ConfigApi* | [**get_storage_config**](docs/apis/tags/ConfigApi.md#get_storage_config) | **get** /config/storage | 
*ConfigApi* | [**setup**](docs/apis/tags/ConfigApi.md#setup) | **post** /setup_lakefs | setup lakeFS and create a first user
*ConfigApi* | [**setup_comm_prefs**](docs/apis/tags/ConfigApi.md#setup_comm_prefs) | **post** /setup_comm_prefs | setup communications preferences
*ExperimentalApi* | [**otf_diff**](docs/apis/tags/ExperimentalApi.md#otf_diff) | **get** /repositories/{repository}/otf/refs/{left_ref}/diff/{right_ref} | perform otf diff
*HealthCheckApi* | [**health_check**](docs/apis/tags/HealthCheckApi.md#health_check) | **get** /healthcheck | 
*ModelImportApi* | [**create_meta_range**](docs/apis/tags/ModelImportApi.md#create_meta_range) | **post** /repositories/{repository}/branches/metaranges | create a lakeFS metarange file from the given ranges
*ModelImportApi* | [**ingest_range**](docs/apis/tags/ModelImportApi.md#ingest_range) | **post** /repositories/{repository}/branches/ranges | create a lakeFS range file from the source uri
*MetadataApi* | [**create_symlink_file**](docs/apis/tags/MetadataApi.md#create_symlink_file) | **post** /repositories/{repository}/refs/{branch}/symlink | creates symlink files corresponding to the given directory
*MetadataApi* | [**get_meta_range**](docs/apis/tags/MetadataApi.md#get_meta_range) | **get** /repositories/{repository}/metadata/meta_range/{meta_range} | return URI to a meta-range file
*MetadataApi* | [**get_range**](docs/apis/tags/MetadataApi.md#get_range) | **get** /repositories/{repository}/metadata/range/{range} | return URI to a range file
*ObjectsApi* | [**copy_object**](docs/apis/tags/ObjectsApi.md#copy_object) | **post** /repositories/{repository}/branches/{branch}/objects/copy | create a copy of an object
*ObjectsApi* | [**delete_object**](docs/apis/tags/ObjectsApi.md#delete_object) | **delete** /repositories/{repository}/branches/{branch}/objects | delete object. Missing objects will not return a NotFound error.
*ObjectsApi* | [**delete_objects**](docs/apis/tags/ObjectsApi.md#delete_objects) | **post** /repositories/{repository}/branches/{branch}/objects/delete | delete objects. Missing objects will not return a NotFound error.
*ObjectsApi* | [**get_object**](docs/apis/tags/ObjectsApi.md#get_object) | **get** /repositories/{repository}/refs/{ref}/objects | get object content
*ObjectsApi* | [**get_underlying_properties**](docs/apis/tags/ObjectsApi.md#get_underlying_properties) | **get** /repositories/{repository}/refs/{ref}/objects/underlyingProperties | get object properties on underlying storage
*ObjectsApi* | [**head_object**](docs/apis/tags/ObjectsApi.md#head_object) | **head** /repositories/{repository}/refs/{ref}/objects | check if object exists
*ObjectsApi* | [**list_objects**](docs/apis/tags/ObjectsApi.md#list_objects) | **get** /repositories/{repository}/refs/{ref}/objects/ls | list objects under a given prefix
*ObjectsApi* | [**stage_object**](docs/apis/tags/ObjectsApi.md#stage_object) | **put** /repositories/{repository}/branches/{branch}/objects | stage an object&#x27;s metadata for the given branch
*ObjectsApi* | [**stat_object**](docs/apis/tags/ObjectsApi.md#stat_object) | **get** /repositories/{repository}/refs/{ref}/objects/stat | get object metadata
*ObjectsApi* | [**upload_object**](docs/apis/tags/ObjectsApi.md#upload_object) | **post** /repositories/{repository}/branches/{branch}/objects | 
*OtfDiffApi* | [**otf_diff**](docs/apis/tags/OtfDiffApi.md#otf_diff) | **get** /repositories/{repository}/otf/refs/{left_ref}/diff/{right_ref} | perform otf diff
*RefsApi* | [**diff_refs**](docs/apis/tags/RefsApi.md#diff_refs) | **get** /repositories/{repository}/refs/{leftRef}/diff/{rightRef} | diff references
*RefsApi* | [**dump_refs**](docs/apis/tags/RefsApi.md#dump_refs) | **put** /repositories/{repository}/refs/dump | Dump repository refs (tags, commits, branches) to object store
*RefsApi* | [**find_merge_base**](docs/apis/tags/RefsApi.md#find_merge_base) | **get** /repositories/{repository}/refs/{sourceRef}/merge/{destinationBranch} | find the merge base for 2 references
*RefsApi* | [**log_commits**](docs/apis/tags/RefsApi.md#log_commits) | **get** /repositories/{repository}/refs/{ref}/commits | get commit log from ref. If both objects and prefixes are empty, return all commits.
*RefsApi* | [**merge_into_branch**](docs/apis/tags/RefsApi.md#merge_into_branch) | **post** /repositories/{repository}/refs/{sourceRef}/merge/{destinationBranch} | merge references
*RefsApi* | [**restore_refs**](docs/apis/tags/RefsApi.md#restore_refs) | **put** /repositories/{repository}/refs/restore | Restore repository refs (tags, commits, branches) from object store
*RepositoriesApi* | [**create_branch_protection_rule**](docs/apis/tags/RepositoriesApi.md#create_branch_protection_rule) | **post** /repositories/{repository}/branch_protection | 
*RepositoriesApi* | [**create_repository**](docs/apis/tags/RepositoriesApi.md#create_repository) | **post** /repositories | create repository
*RepositoriesApi* | [**delete_branch_protection_rule**](docs/apis/tags/RepositoriesApi.md#delete_branch_protection_rule) | **delete** /repositories/{repository}/branch_protection | 
*RepositoriesApi* | [**delete_repository**](docs/apis/tags/RepositoriesApi.md#delete_repository) | **delete** /repositories/{repository} | delete repository
*RepositoriesApi* | [**get_branch_protection_rules**](docs/apis/tags/RepositoriesApi.md#get_branch_protection_rules) | **get** /repositories/{repository}/branch_protection | get branch protection rules
*RepositoriesApi* | [**get_repository**](docs/apis/tags/RepositoriesApi.md#get_repository) | **get** /repositories/{repository} | get repository
*RepositoriesApi* | [**list_repositories**](docs/apis/tags/RepositoriesApi.md#list_repositories) | **get** /repositories | list repositories
*RetentionApi* | [**delete_garbage_collection_rules**](docs/apis/tags/RetentionApi.md#delete_garbage_collection_rules) | **delete** /repositories/{repository}/gc/rules | 
*RetentionApi* | [**get_garbage_collection_rules**](docs/apis/tags/RetentionApi.md#get_garbage_collection_rules) | **get** /repositories/{repository}/gc/rules | 
*RetentionApi* | [**prepare_garbage_collection_commits**](docs/apis/tags/RetentionApi.md#prepare_garbage_collection_commits) | **post** /repositories/{repository}/gc/prepare_commits | save lists of active and expired commits for garbage collection
*RetentionApi* | [**prepare_garbage_collection_uncommitted**](docs/apis/tags/RetentionApi.md#prepare_garbage_collection_uncommitted) | **post** /repositories/{repository}/gc/prepare_uncommited | save repository uncommitted metadata for garbage collection
*RetentionApi* | [**set_garbage_collection_rules**](docs/apis/tags/RetentionApi.md#set_garbage_collection_rules) | **post** /repositories/{repository}/gc/rules | 
*StagingApi* | [**get_physical_address**](docs/apis/tags/StagingApi.md#get_physical_address) | **get** /repositories/{repository}/branches/{branch}/staging/backing | get a physical address and a return token to write object to underlying storage
*StagingApi* | [**link_physical_address**](docs/apis/tags/StagingApi.md#link_physical_address) | **put** /repositories/{repository}/branches/{branch}/staging/backing | associate staging on this physical address with a path
*StatisticsApi* | [**post_stats_events**](docs/apis/tags/StatisticsApi.md#post_stats_events) | **post** /statistics | post stats events, this endpoint is meant for internal use only
*TagsApi* | [**create_tag**](docs/apis/tags/TagsApi.md#create_tag) | **post** /repositories/{repository}/tags | create tag
*TagsApi* | [**delete_tag**](docs/apis/tags/TagsApi.md#delete_tag) | **delete** /repositories/{repository}/tags/{tag} | delete tag
*TagsApi* | [**get_tag**](docs/apis/tags/TagsApi.md#get_tag) | **get** /repositories/{repository}/tags/{tag} | get tag
*TagsApi* | [**list_tags**](docs/apis/tags/TagsApi.md#list_tags) | **get** /repositories/{repository}/tags | list tags
*TemplatesApi* | [**expand_template**](docs/apis/tags/TemplatesApi.md#expand_template) | **get** /templates/{template_location} | 

## Documentation For Models

 - [AccessKeyCredentials](docs/models/AccessKeyCredentials.md)
 - [ActionRun](docs/models/ActionRun.md)
 - [ActionRunList](docs/models/ActionRunList.md)
 - [AuthCapabilities](docs/models/AuthCapabilities.md)
 - [AuthenticationToken](docs/models/AuthenticationToken.md)
 - [BranchCreation](docs/models/BranchCreation.md)
 - [BranchProtectionRule](docs/models/BranchProtectionRule.md)
 - [CherryPickCreation](docs/models/CherryPickCreation.md)
 - [CommPrefsInput](docs/models/CommPrefsInput.md)
 - [Commit](docs/models/Commit.md)
 - [CommitCreation](docs/models/CommitCreation.md)
 - [CommitList](docs/models/CommitList.md)
 - [Credentials](docs/models/Credentials.md)
 - [CredentialsList](docs/models/CredentialsList.md)
 - [CredentialsWithSecret](docs/models/CredentialsWithSecret.md)
 - [CurrentUser](docs/models/CurrentUser.md)
 - [Diff](docs/models/Diff.md)
 - [DiffList](docs/models/DiffList.md)
 - [Error](docs/models/Error.md)
 - [FindMergeBaseResult](docs/models/FindMergeBaseResult.md)
 - [ForgotPasswordRequest](docs/models/ForgotPasswordRequest.md)
 - [GarbageCollectionConfig](docs/models/GarbageCollectionConfig.md)
 - [GarbageCollectionPrepareRequest](docs/models/GarbageCollectionPrepareRequest.md)
 - [GarbageCollectionPrepareResponse](docs/models/GarbageCollectionPrepareResponse.md)
 - [GarbageCollectionRule](docs/models/GarbageCollectionRule.md)
 - [GarbageCollectionRules](docs/models/GarbageCollectionRules.md)
 - [Group](docs/models/Group.md)
 - [GroupCreation](docs/models/GroupCreation.md)
 - [GroupList](docs/models/GroupList.md)
 - [HookRun](docs/models/HookRun.md)
 - [HookRunList](docs/models/HookRunList.md)
 - [ImportPagination](docs/models/ImportPagination.md)
 - [IngestRangeCreationResponse](docs/models/IngestRangeCreationResponse.md)
 - [LoginConfig](docs/models/LoginConfig.md)
 - [LoginInformation](docs/models/LoginInformation.md)
 - [Merge](docs/models/Merge.md)
 - [MergeResult](docs/models/MergeResult.md)
 - [MergeResultSummary](docs/models/MergeResultSummary.md)
 - [MetaRangeCreation](docs/models/MetaRangeCreation.md)
 - [MetaRangeCreationResponse](docs/models/MetaRangeCreationResponse.md)
 - [NextStep](docs/models/NextStep.md)
 - [ObjectCopyCreation](docs/models/ObjectCopyCreation.md)
 - [ObjectError](docs/models/ObjectError.md)
 - [ObjectErrorList](docs/models/ObjectErrorList.md)
 - [ObjectStageCreation](docs/models/ObjectStageCreation.md)
 - [ObjectStats](docs/models/ObjectStats.md)
 - [ObjectStatsList](docs/models/ObjectStatsList.md)
 - [ObjectUserMetadata](docs/models/ObjectUserMetadata.md)
 - [OtfDiffEntry](docs/models/OtfDiffEntry.md)
 - [OtfDiffList](docs/models/OtfDiffList.md)
 - [Pagination](docs/models/Pagination.md)
 - [PathList](docs/models/PathList.md)
 - [Policy](docs/models/Policy.md)
 - [PolicyList](docs/models/PolicyList.md)
 - [PrepareGCUncommittedRequest](docs/models/PrepareGCUncommittedRequest.md)
 - [PrepareGCUncommittedResponse](docs/models/PrepareGCUncommittedResponse.md)
 - [RangeMetadata](docs/models/RangeMetadata.md)
 - [Ref](docs/models/Ref.md)
 - [RefList](docs/models/RefList.md)
 - [RefsDump](docs/models/RefsDump.md)
 - [Repository](docs/models/Repository.md)
 - [RepositoryCreation](docs/models/RepositoryCreation.md)
 - [RepositoryList](docs/models/RepositoryList.md)
 - [ResetCreation](docs/models/ResetCreation.md)
 - [RevertCreation](docs/models/RevertCreation.md)
 - [Setup](docs/models/Setup.md)
 - [SetupState](docs/models/SetupState.md)
 - [StageRangeCreation](docs/models/StageRangeCreation.md)
 - [StagingLocation](docs/models/StagingLocation.md)
 - [StagingMetadata](docs/models/StagingMetadata.md)
 - [Statement](docs/models/Statement.md)
 - [StatsEvent](docs/models/StatsEvent.md)
 - [StatsEventsList](docs/models/StatsEventsList.md)
 - [StorageConfig](docs/models/StorageConfig.md)
 - [StorageURI](docs/models/StorageURI.md)
 - [TagCreation](docs/models/TagCreation.md)
 - [UnderlyingObjectProperties](docs/models/UnderlyingObjectProperties.md)
 - [UpdatePasswordByToken](docs/models/UpdatePasswordByToken.md)
 - [User](docs/models/User.md)
 - [UserCreation](docs/models/UserCreation.md)
 - [UserList](docs/models/UserList.md)
 - [VersionConfig](docs/models/VersionConfig.md)

## Documentation For Authorization


## basic_auth

- **Type**: HTTP basic authentication


## jwt_token

- **Type**: Bearer authentication (JWT)


## cookie_auth

- **Type**: API key
- **API key parameter name**: internal_auth_session
- **Location**: 


## oidc_auth

- **Type**: API key
- **API key parameter name**: oidc_auth_session
- **Location**: 

 Authentication schemes defined for the API:
## saml_auth

- **Type**: API key
- **API key parameter name**: saml_auth_session
- **Location**: 


## Author

services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io
services@treeverse.io

## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in lakefs_client.apis and lakefs_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from lakefs_client.apis.default_api import DefaultApi`
- `from lakefs_client.model.pet import Pet`

Solution 1:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import lakefs_client
from lakefs_client.apis import *
from lakefs_client.models import *
```
